{% if job_data %}
{% include "history-conversion-details-stats.html" %}
{% if job_data['statistics']['task_success'] %}
{% set file_data = job_data['source'] %} {% include "history-conversion-details-video-data.html" %}
{% set file_data = job_data['destination'] %} {% include "history-conversion-details-video-data.html" %}
{% end %}
{% else %}
Conversion Details

No conversion details found for this task.

{% end %}